// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef AKONADIMIME_VERSION_H
#define AKONADIMIME_VERSION_H

#define AKONADIMIME_VERSION_STRING "6.7.90"
#define AKONADIMIME_VERSION_MAJOR 6
#define AKONADIMIME_VERSION_MINOR 7
#define AKONADIMIME_VERSION_PATCH 90
#define AKONADIMIME_VERSION ((6<<16)|(7<<8)|(90))

#endif
